summaryrefslogtreecommitdiffstats
path: root/kdf/listview.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
commit955e20356d63ed405198c8143617a8a0ca8bfc02 (patch)
tree9a9ab22c86d212a5655014ad752e96b04c0c86a9 /kdf/listview.cpp
parentbf280726d5d22f33d33e4f9e771220c725249407 (diff)
downloadtdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.tar.gz
tdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit bf280726d5d22f33d33e4f9e771220c725249407.
Diffstat (limited to 'kdf/listview.cpp')
-rw-r--r--kdf/listview.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kdf/listview.cpp b/kdf/listview.cpp
index b9274c3..49021ee 100644
--- a/kdf/listview.cpp
+++ b/kdf/listview.cpp
@@ -20,7 +20,7 @@
//
// 1999-11-28 Espen Sand
// The purpose of this class is:
// 1) Easily set minimum number of visible items and to adjust the sizeHint()
// 2) Provide a pixmap collection
//
@@ -46,20 +46,20 @@ void CListView::setVisibleItem( int visibleItem, bool updateSize )
mVisibleItem = TQMAX( 1, visibleItem );
if( updateSize == true )
{
- TQSize s = sizeHint();
- setMinimumSize( s.width() + verticalScrollBar()->sizeHint().width() +
+ TQSize s = tqsizeHint();
+ setMinimumSize( s.width() + verticalScrollBar()->tqsizeHint().width() +
lineWidth() * 2, s.height() );
}
}
-TQSize CListView::sizeHint( void ) const
+TQSize CListView::tqsizeHint( void ) const
{
- TQSize s = TQListView::sizeHint();
+ TQSize s = TQListView::tqsizeHint();
int h = fontMetrics().height() + 2*itemMargin();
if( h % 2 > 0 ) { h++; }
- s.setHeight( h*mVisibleItem + lineWidth()*2 + header()->sizeHint().height());
+ s.setHeight( h*mVisibleItem + lineWidth()*2 + header()->tqsizeHint().height());
return( s );
}
@@ -20,7 +20,7 @@
// 1999-11-28 Espen Sand
// The purpose of this class is:
-// 1) Easily set minimum number of visible items and to adjust the sizeHint()
+// 1) Easily set minimum number of visible items and to adjust the tqsizeHint()
// 2) Provide a pixmap collection
//